@@ -7,9 +7,10 @@ import xml.etree.ElementTree as ET
 import saspy
 import logging
 import tempfile
+from .globals import java, all_obj_types
 
 
-def create_saspyconn(sasobjsp_host, sasobjsp_port, java='/usr/bin/java'):
+def create_saspyconn(sasobjsp_host, sasobjsp_port, java=java):
     saspy_conn = tempfile.NamedTemporaryFile(mode='w+', delete=True)
     saspy_conn.write(f"""SAS_config_names=['sasconnection']
 SAS_config_options = {{'lock_down': False,
@@ -32,7 +33,7 @@ class AbstractSAS(saspy.SASsession):
                        sasobjsp_pass,
                        sasobjsp_host,
                        sasobjsp_port,
-                       java='/usr/bin/java',
+                       java=java,
                        **kwargs):
         logging.debug('Initializing Abstract SAS class')
         self.sasobjsp_host = sasobjsp_host
@@ -50,11 +51,24 @@ class AbstractSAS(saspy.SASsession):
                                            omruser=self.sasobjsp_user,
                                            omrpw=self.sasobjsp_pass)
 
-    def read_dataset(self, libname, tablename):
+    def read_dataset(self, tablename: str, libname: str = 'WORK'):
+        """
+        Read data From SAS. Data is returned is in the form of Pandas DataFrame.
+        :param libname: library, is which table is stored
+        :param tablename: name of the table, you want to read
+        :return: pd.Dataframe
+        """
         df = self.sasdata2dataframe(table=tablename, libref=libname)
         return df
 
-    def write_dataset(self, df, libname, tablename):
+    def write_dataset(self, df, tablename: str, libname: str = 'WORK'):
+        """
+        Writes dataframe To SAS.
+        :param df: dataframe to write
+        :param tablename: table, in which you want to write data.
+        :param libname: library, in which you want to write data.
+        :return:
+        """
         result = self.dataframe2sasdata(df=df, table=tablename, libref=libname)
         return result
 
@@ -62,8 +76,22 @@ class AbstractSAS(saspy.SASsession):
         libs = self.assigned_librefs()
         return libs
 
+    def run_script(self, script):
+        if script:
+            pass
+        return self.submit(code=script)
 
-def get_sas_connect(sasobjsp_host, sasobjsp_port, sasobjsp_user, sasobjsp_pass, java='/usr/bin/java'):
+
+def get_sas_connect(sasobjsp_host, sasobjsp_port, sasobjsp_user, sasobjsp_pass, java=java):
+    """
+    LEGACY!!!!!
+    :param sasobjsp_host:
+    :param sasobjsp_port:
+    :param sasobjsp_user:
+    :param sasobjsp_pass:
+    :param java:
+    :return:
+    """
     saspy_conn = tempfile.NamedTemporaryFile(mode='w+', delete=True)
     saspy_conn.write(f"""SAS_config_names=['sasconnection']
 SAS_config_options = {{'lock_down': False,
@@ -87,7 +115,7 @@ sasconnection = {{'java'      : '{java}',
     return sas
 
 
-def get_objects_from_spk(spk_path, log_path, object_types=None):
+def get_objects_from_spk(spk_path: str, log_path: str, object_types: list = None):
     """
     Extracts information about metadata objects from spk
     :param spk_path: path (str) to spk
@@ -101,12 +129,8 @@ def get_objects_from_spk(spk_path, log_path, object_types=None):
     list of path's --- FIX THAT DESCRIPTION!!!
     """
     logging.info(f"Object extraction from {spk_path} started.")
-
     log_lines = []
     validation_status = False
-    all_obj_types = ['DeployedFlow', 'DeployedJob', 'ExternalFile', 'Folder',
-                     'Library', 'Role', 'Server', 'StoredProcess', 'Table',
-                     'User', 'Job']
     if not object_types:
         object_types = all_obj_types
     extracted_objects = {i: [] for i in object_types}
@@ -201,7 +225,7 @@ def import_spk(sas_conn_file_path, spk_path, log_path, import_package_jar_path,
             logging.info(f"Import process finished successfully")
         if import_process.returncode == 4:
             execution_status = True
-            logging.warn(f"Import process finished with Warnings")
+            logging.warning(f"Import process finished with Warnings")
             warnings = True
     except Exception as e:
         execution_log_lines += str(e)
@@ -348,7 +372,7 @@ def redeploy_jobs(objects_list,
         elif redeploy_process.returncode == 4:
             execution_status = True
             warnings = True
-            logging.warn(f"Redeploy process finished with warnings.")
+            logging.warning(f"Redeploy process finished with warnings.")
             # execution_log_lines += redeploy_process.stdout
         else:
             # execution_log_lines += redeploy_process.stderr
@@ -397,7 +421,7 @@ def export_objects(objects_list, log_path, sas_conn_file_path,
             # print(f'Export process finished with warnings.')
             execution_status = True
             warnings = True
-            logging.warnings(f"Warnings during export process. Check log: {log_path}")
+            logging.warning(f"Warnings during export process. Check log: {log_path}")
             # logging.info(f"Objects exported to {package_path}.")
             # execution_log_lines += redeploy_process.stdout
         else:
@@ -442,11 +466,11 @@ def backup_metadata(backup_script_path, comment, sas_conn_file_path, log_path):
         elif backup_process.returncode == 4:
             backup_success = False
             backup_name = str(backup_process.stdout.readline()).split()[2]
-            logging.warn(f"Backup {backup_name} completed with WARNINGS.")
+            logging.warning(f"Backup {backup_name} completed with WARNINGS.")
             warnings = True
         else:
             # execution_log_lines += backup_process.stderr
-            logging.warn(f"Backup NOT completed!")
+            logging.warning(f"Backup NOT completed!")
     except Exception as e:
         execution_log_lines += str(e)
         logging.error(f"Errors during backup process! {str(e)}")
@@ -486,10 +510,10 @@ def recover_metadata(recover_script_path, backup_name, comment,
         elif backup_process.returncode == 4:
             restore_success = False
             warnings = True
-            logging.warn(f"Restore from backup {backup_name} finished with warnings")
+            logging.warning(f"Restore from backup {backup_name} finished with warnings")
             # execution_log_lines += redeploy_process.stdout
         else:
-            logging.warn(f"Restore from backup {backup_name} not finished!")
+            logging.warning(f"Restore from backup {backup_name} not finished!")
             # execution_log_lines += redeploy_process.stderr
     except Exception as e:
         execution_log_lines += str(e)
